/**
 * @file
 * Javascript functionality for component accordion.
 */

(function ($, Drupal) {

  'use strict';
  Drupal.componentGridCarousel = Drupal.componentGridCarousel || {};
  Drupal.behaviors.gridCarousel = {
    attach: function (context) {
      Drupal.componentGridCarousel.carouselImages(context);
      Drupal.componentGridCarousel.carouselHiddenFields();
    }
  }

  Drupal.componentGridCarousel.carouselImages = function (context) {
    var $carousels = $('.component-builder.component-wrapper--type-grid_carousel', context).once('wrapperGridCarousel');
    if ($carousels.length > 0) {
      $carousels.each(function () {
        var $this = $(this);
        const number = $this.attr('data-carousel-columns') || 2;
        var $items = $this.find('.component-wrapper--content > .field--name-field-grid-carousel.field__items');
        Drupal.componentGridCarousel.carouselImageSlide($items, number);
      })
    }
  }

  Drupal.componentGridCarousel.carouselImageSlide = function ($selector, numberShow = 2, showDot = false) {
    if ($selector.length > 0) {
      if ($selector.find('.field__item').length <= numberShow) {
        showDot = false;
      }
      // showDot = true;
      $selector.not('.slick-initialized').slick({
        centerMode: true,
        autoplaySpeed: 2000,
        rtl: drupalSettings['components']['grid_carousel']['rtl'],
        dots: showDot,
        infinite: true,
        speed: 300,
        slidesToShow: numberShow,
        slidesToScroll: 1,
        responsive: [
          {
            breakpoint: 1024,
            settings: {
              centerMode: true,
              autoplaySpeed: 2000,
              slidesToShow: numberShow,
              slidesToScroll: 1,
              infinite: true,
              dots: showDot
            }
          },
          {
            breakpoint: 768,
            settings: {
              centerMode: true,
              autoplaySpeed: 2000,
              slidesToShow: 1,
              slidesToScroll: 1
            }
          },
          {
            breakpoint: 480,
            settings: {
              centerMode: true,
              autoplaySpeed: 2000,
              slidesToShow: 1,
              slidesToScroll: 1
            }
          }
        ]
      });
    }
  }

  Drupal.componentGridCarousel.carouselHiddenFields = function (context) {
    var $carouselItems = $('.component-builder.component-wrapper--type-grid-carousel', context).once('hiddenFields');
    if ($carouselItems.length > 0) {
      $carouselItems.each(function () {
        var $this = $(this);
        var $hidden_fields = $this.attr('data-hidden-field') || [];
        $hidden_fields = JSON.parse($hidden_fields);
        if ($hidden_fields) {
          $($this.find('.slick-slide')).each(function () {
            for (let i = 0; i < $hidden_fields.length; i++) {
              $(this).find('.field--name-' + $hidden_fields[i].replace("_", "-")).each(function () {
                $(this).css("display", "none");
              });
            }
          });
        }
      })
    }
  }
})(jQuery, Drupal);
