/**
 * @file
 * Behaviors for the component_wrapper widget in node add form.
 */

(function ($, Drupal) {
  'use strict';

  Drupal.componentWrapper = Drupal.componentWrapper || {};
  Drupal.behaviors.componentWrapper = {
    attach: function (context) {
      Drupal.componentWrapper.setEvent(context);
    }
  }

  Drupal.componentWrapper.setEvent = function (context) {
    $('.field--type-entity-reference.field--name-component-type', context).once('name-component-type').each(function () {
      var $select = $(this).find('select');
      // console.log($select);
      if ($select.length > 0) {
        Drupal.componentWrapper.showFieldReferenceWithComponentType($select);
        $select.change(function () {
          Drupal.componentWrapper.showFieldReferenceWithComponentType($(this))
        })
      }
      let $selectProperties = $('#component-attributes-wrapper--composite [class*=component-attributes-composite-properties-options-column] select');
      Drupal.componentWrapper.showFieldReferenceWithColumn($selectProperties);
      $('#component-attributes-wrapper--composite [class*=component-attributes-composite-properties-options-column] select', context).once('change-properties-component').each(function () {
        $(this).change(function () {
          Drupal.componentWrapper.showFieldReferenceWithColumn($(this));
        })
      })
    })
  }

  Drupal.componentWrapper.showFieldReferenceWithComponentType = function ($selector, allowedFields = []) {
    var $parentSelect = $selector.closest('.field--type-entity-reference.field--name-component-type');
    var $parentIEF = $parentSelect.parent();
    var $complexField = $parentIEF.children('.field--type-entity-reference.field--widget-inline-entity-form-complex, .field--type-entity-reference.field--widget-inline-entity-form-simple');
    Drupal.componentWrapper.displayElement($complexField, 'none');
    const selectValue = $selector.val();
    var isSelect = false;
    if (parseInt(selectValue) == selectValue) {
      isSelect = true;
    }
    var textSelect = $selector.find('option:selected').text();
    if (textSelect.length > 0) {
      textSelect = textSelect.toLowerCase().replaceAll(' ', '-');
      const machineComponent = textSelect.replaceAll('-', '_');
      if (allowedFields.length === 0) {
        if (machineComponent === 'composite') {
          const $select = $parentIEF.find('#component-attributes-wrapper--composite [class*=component-attributes-composite-properties-options-column] select');
          if ($select.length > 0) {
            const selectValue = $select.val();
            if (isSelect) {
              allowedFields = Drupal.componentWrapper.getCompositeAllowed(selectValue, false);
            }
          }
        } else if (isSelect) {
          allowedFields = [textSelect];
        }
        if (machineComponent === 'timeline') {
          Drupal.componentWrapper.showFieldForComponentWithSubWrapper($('.field--name-field-timelines-wrapper'), 'Timeline', "field-timelines-wrapper-wrapper", "field--name-field-timeline");
        }
        if (machineComponent === 'tabs') {
          Drupal.componentWrapper.showFieldForComponentWithSubWrapper($('.field--name-field-tabs-column'), 'Tabs', "field-tabs-column-wrapper", "field--name-field-tabs");
        }
        if (machineComponent === 'tabs_simple') {
          Drupal.componentWrapper.showFieldForComponentWithSubWrapper($('.field--name-field-tabs-column'), 'Tabs Simple', "field-tabs-column-wrapper", "field--name-field-tabs-simple");
        }
      }
      var allowItemClass = [];
      for (let key in allowedFields) {
        // Test hide field.
        let fieldClass = 'field--name-field-' + allowedFields[key];
        let itemClass = '.field--type-entity-reference.field--widget-inline-entity-form-complex.' + fieldClass + ', .field--type-entity-reference.field--widget-inline-entity-form-simple.' + fieldClass;
        allowItemClass.push(itemClass);
      }
      if (allowItemClass.length > 0) {
        allowItemClass = allowItemClass.join(',');
        var $allowItem = $parentIEF.children(allowItemClass);
        if ($allowItem.length > 0) {
          if (!$parentIEF.children(allowItemClass).hasClass('field--name-field-timeline')
            && !$parentIEF.children(allowItemClass).hasClass('field--name-field-tabs')
            && !$parentIEF.children(allowItemClass).hasClass('field--name-field-tabs-simple')
          ) {
            Drupal.componentWrapper.displayElement($parentIEF.children(allowItemClass));
          }
        }
      }

      Drupal.componentWrapper.displayElement($parentIEF.find('.component-attributes-wrapper--item'), 'none');
      Drupal.componentWrapper.displayElement($parentIEF.find('.component-attributes-wrapper--tabs.component-attributes-wrapper--item'), 'none');
      if (isSelect) {
        var $properties = $parentIEF.find('#component-attributes-wrapper--' + machineComponent);
        Drupal.componentWrapper.displayElement($properties);
      }
    }
  }

  Drupal.componentWrapper.showFieldForComponentWithSubWrapper = function ($field_selected, $allowedOptionSubWrapper, $field_wrapper, $field_item) {
    if ($field_selected.length > 0) {
      $field_selected.css('display', 'block');
      $(document).ajaxStop(function () {
        let $wrapper_custom = $field_selected.find('.wrapper-display--custom.js-form-wrapper.form-wrapper');
        if ($wrapper_custom.length > 0) {
          $wrapper_custom.css('display', 'none');
        }

        let $form_select = $field_selected.find('select.form-select.form-element.form-element--type-select[id*="component-type"]');
        if ($form_select.length > 0) {
          let $selectOptions = $form_select.find("option");
          if ($selectOptions.length > 0) {
            $selectOptions.each(function () {
              if ($(this).text() === $allowedOptionSubWrapper) {
                let idTabContent = $(this).attr('value');
                $form_select.val(idTabContent).change();
                $form_select.css({'display': 'none'});

                let $label = $form_select.siblings('.form-item__label');
                $label.css({'display': 'none'});
              }
            });
          }
        }

        let $inner_wrapper = $field_selected.find("[id*='" + $field_wrapper + "']");
        if ($inner_wrapper.length > 0) {
          $inner_wrapper.css('display', 'none');
        }

        let $field_item_select = $field_selected.find('.field--type-entity-reference.' + $field_item + '.js-form-wrapper.form-wrapper');
        if ($field_item_select.length > 0) {
          $field_item_select.css('display', 'block');
        }

        const parent_field_hidden = '.field--name-field-timelines-wrapper, .field--name-field-tabs-column';
        Drupal.componentWrapper.hiddenChildFields(parent_field_hidden);
      });
    }
  }

  Drupal.componentWrapper.showFieldReferenceWithColumn = function ($selector) {
    $selector = $($selector);
    if ($selector.length != 1) {
      return;
    }
    var numberColumn = $selector.val();
    var $parentWrapperProperties = $selector.closest('#component-attributes-wrapper');
    var $parentIEF = $parentWrapperProperties.parent();

    let allowedColumnClass = [];
    let allColumnClass = [
      '.field--type-entity-reference.field--widget-inline-entity-form-complex.field--name-field-left-column',
      '.field--type-entity-reference.field--widget-inline-entity-form-complex.field--name-field-middle-column',
      '.field--type-entity-reference.field--widget-inline-entity-form-complex.field--name-field-right-column',
      '.field--type-entity-reference.field--widget-inline-entity-form-simple.field--name-field-left-column',
      '.field--type-entity-reference.field--widget-inline-entity-form-simple.field--name-field-middle-column',
      '.field--type-entity-reference.field--widget-inline-entity-form-simple.field--name-field-right-column'
    ];
    if (numberColumn == 1) {
      allowedColumnClass = [
        '.field--type-entity-reference.field--widget-inline-entity-form-complex.field--name-field-left-column',
        '.field--type-entity-reference.field--widget-inline-entity-form-simple.field--name-field-left-column'
      ];
    } else if (numberColumn == 2) {
      allowedColumnClass = [
        '.field--type-entity-reference.field--widget-inline-entity-form-complex.field--name-field-left-column',
        '.field--type-entity-reference.field--widget-inline-entity-form-simple.field--name-field-left-column',
        '.field--type-entity-reference.field--widget-inline-entity-form-complex.field--name-field-right-column',
        '.field--type-entity-reference.field--widget-inline-entity-form-simple.field--name-field-right-column'
      ];
    } else if (numberColumn == 3) {
      allowedColumnClass = allColumnClass;
    }
    let allowedColumnClassString = allowedColumnClass.join(',')
    let allColumnClassString = allColumnClass.join(',')
    Drupal.componentWrapper.displayElement($parentIEF.find(allColumnClassString), 'none');
    Drupal.componentWrapper.displayElement($parentIEF.find(allowedColumnClassString));
  }

  Drupal.componentWrapper.displayElement = function (element, display = 'block') {
    $(element).css({'display': display});
  }

  Drupal.componentWrapper.getCompositeAllowed = function (numberColumn, full_class = true) {
    var allowedColumnClass = [];
    if (full_class) {
      var allColumnClass = [
        '.field--type-entity-reference.field--widget-inline-entity-form-complex.field--name-field-left-column',
        '.field--type-entity-reference.field--widget-inline-entity-form-complex.field--name-field-middle-column',
        '.field--type-entity-reference.field--widget-inline-entity-form-complex.field--name-field-right-column',
        '.field--type-entity-reference.field--widget-inline-entity-form-simple.field--name-field-left-column',
        '.field--type-entity-reference.field--widget-inline-entity-form-simple.field--name-field-middle-column',
        '.field--type-entity-reference.field--widget-inline-entity-form-simple.field--name-field-right-column'
      ];
      if (numberColumn == 1) {
        allowedColumnClass = [
          '.field--type-entity-reference.field--widget-inline-entity-form-complex.field--name-field-left-column',
          '.field--type-entity-reference.field--widget-inline-entity-form-simple.field--name-field-left-column'
        ];
      } else if (numberColumn == 2) {
        allowedColumnClass = [
          '.field--type-entity-reference.field--widget-inline-entity-form-complex.field--name-field-left-column',
          '.field--type-entity-reference.field--widget-inline-entity-form-simple.field--name-field-left-column',
          '.field--type-entity-reference.field--widget-inline-entity-form-complex.field--name-field-right-column',
          '.field--type-entity-reference.field--widget-inline-entity-form-simple.field--name-field-right-column'
        ];
      } else if (numberColumn == 3) {
        allowedColumnClass = allColumnClass;
      }
    } else {
      var allColumnClass = [
        'left-column',
        'middle-column',
        'right-column',
      ];
      if (numberColumn == 1) {
        allowedColumnClass = [
          'left-column',
        ];
      } else if (numberColumn == 2) {
        allowedColumnClass = [
          'left-column',
          'right-column',
        ];
      } else if (numberColumn == 3) {
        allowedColumnClass = allColumnClass;
      }
    }
    return allowedColumnClass
  }

  Drupal.componentWrapper.hiddenChildFields = function (selector, fields_hidden = '', level = 1) {
    const $selector = $(selector);
    fields_hidden = '.component-attributes-wrapper--item';
    if ($selector.length > 0) {
      const $fields = $selector.find(fields_hidden);
      if ($fields.length > 0) {
        $fields.hide();
      }
    }
  }

})(jQuery, Drupal);
